==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/content/trains/station/NoShadowFontWrapper.java <==
package com.zurrtum.create.client.content.trains.station;

import org.joml.Matrix4f;

import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_4597;
import net.minecraft.class_5225;
import net.minecraft.class_5348;
import net.minecraft.class_5481;

public class NoShadowFontWrapper extends class_327 {
    private final class_327 wrapped;

    public NoShadowFontWrapper(class_327 wrapped) {
        super(wrapped.field_61529);
        this.wrapped = wrapped;
    }

    @Override
    public void method_27522(
        class_2561 text,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_27522(text, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public void method_27521(
        String string,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_27521(string, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public void method_22942(
        class_5481 text,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_22942(text, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public int method_44378(class_5348 text, int maxWidth) {
        return wrapped.method_44378(text, maxWidth);
    }

    @Override
    public String method_1721(String text) {
        return wrapped.method_1721(text);
    }

    @Override
    public void method_37296(
        class_5481 text,
        float x,
        float y,
        int color,
        int outlineColor,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        int light
    ) {
        wrapped.method_37296(text, x, y, color, outlineColor, matrix, vertexConsumers, light);
    }

    @Override
    public int method_1727(String text) {
        return wrapped.method_1727(text);
    }

    @Override
    public int method_30880(class_5481 text) {
        return wrapped.method_30880(text);
    }

    @Override
    public int method_27525(class_5348 text) {
        return wrapped.method_27525(text);
    }

    @Override
    public String method_27523(String text, int maxWidth) {
        return wrapped.method_27523(text, maxWidth);
    }

    @Override
    public String method_27524(String text, int maxWidth, boolean backwards) {
        return wrapped.method_27524(text, maxWidth, backwards);
    }

    @Override
    public class_5348 method_1714(class_5348 text, int width) {
        return wrapped.method_1714(text, width);
    }

    @Override
    public int method_1713(String text, int maxWidth) {
        return wrapped.method_1713(text, maxWidth);
    }

    @Override
    public List<class_5481> method_1728(class_5348 text, int width) {
        return wrapped.method_1728(text, width);
    }

    @Override
    public List<class_5348> method_72101(class_5348 text, int width) {
        return wrapped.method_72101(text, width);
    }

    @Override
    public boolean method_1726() {
        return wrapped.method_1726();
    }

    @Override
    public class_5225 method_27527() {
        return wrapped.method_27527();
    }

    @Override
    public class_11465 method_71796(String string, float x, float y, int color, boolean shadow, int backgroundColor) {
        return wrapped.method_71796(string, x, y, color, false, backgroundColor);
    }

    @Override
    public class_11465 method_71795(class_5481 text, float x, float y, int color, boolean shadow, int backgroundColor) {
        return wrapped.method_71795(text, x, y, color, false, backgroundColor);
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/content/trains/station/NoShadowFontWrapper.java <==
package com.zurrtum.create.client.content.trains.station;

import org.joml.Matrix4f;

import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_327;
import net.minecraft.class_4597;
import net.minecraft.class_5225;
import net.minecraft.class_5348;
import net.minecraft.class_5481;

public class NoShadowFontWrapper extends class_327 {
    private final class_327 wrapped;

    public NoShadowFontWrapper(class_327 wrapped) {
        super(wrapped.field_61529);
        this.wrapped = wrapped;
    }

    @Override
    public void method_27522(
        class_2561 text,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_27522(text, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public void method_27521(
        String string,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_27521(string, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public void method_22942(
        class_5481 text,
        float x,
        float y,
        int color,
        boolean shadow,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        class_6415 layerType,
        int backgroundColor,
        int light
    ) {
        wrapped.method_22942(text, x, y, color, false, matrix, vertexConsumers, layerType, backgroundColor, light);
    }

    @Override
    public int method_44378(class_5348 text, int maxWidth) {
        return wrapped.method_44378(text, maxWidth);
    }

    @Override
    public String method_1721(String text) {
        return wrapped.method_1721(text);
    }

    @Override
    public void method_37296(
        class_5481 text,
        float x,
        float y,
        int color,
        int outlineColor,
        Matrix4f matrix,
        class_4597 vertexConsumers,
        int light
    ) {
        wrapped.method_37296(text, x, y, color, outlineColor, matrix, vertexConsumers, light);
    }

    @Override
    public int method_1727(String text) {
        return wrapped.method_1727(text);
    }

    @Override
    public int method_30880(class_5481 text) {
        return wrapped.method_30880(text);
    }

    @Override
    public int method_27525(class_5348 text) {
        return wrapped.method_27525(text);
    }

    @Override
    public String method_27523(String text, int maxWidth) {
        return wrapped.method_27523(text, maxWidth);
    }

    @Override
    public String method_27524(String text, int maxWidth, boolean backwards) {
        return wrapped.method_27524(text, maxWidth, backwards);
    }

    @Override
    public class_5348 method_1714(class_5348 text, int width) {
        return wrapped.method_1714(text, width);
    }

    @Override
    public List<class_5481> method_1728(class_5348 text, int width) {
        return wrapped.method_1728(text, width);
    }

    @Override
    public List<class_5348> method_72101(class_5348 text, int width) {
        return wrapped.method_72101(text, width);
    }

    @Override
    public boolean method_1726() {
        return wrapped.method_1726();
    }

    @Override
    public class_5225 method_27527() {
        return wrapped.method_27527();
    }

    @Override
    public class_11465 method_71796(String string, float x, float y, int color, boolean shadow, int backgroundColor) {
        return wrapped.method_71796(string, x, y, color, false, backgroundColor);
    }

    @Override
    public class_11465 method_71795(
        class_5481 text,
        float x,
        float y,
        int color,
        boolean shadow,
        boolean includeEmpty,
        int backgroundColor
    ) {
        return wrapped.method_71795(text, x, y, color, false, includeEmpty, backgroundColor);
    }
}
